#!/usr/bin/perl

# Processes l1_logreg results file into a UCSC custom track for viewing.
# Trims 500nt from results file ends to produce resulting veiw.

#
#  Copyright (C) 2008  Molly Megraw
# 
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#  
#  Contact: molly.megraw@duke.edu
#  
#

$TRIM = 500;

$step = shift;
$inFile = shift; # l1_logreg results file
$locsFile = shift; # tab-delimited file defining sequence location (label, chr, start, end, strand)
$outdir = shift; # directory for output file

@dirparts = split(/\//, $inFile);
$fname = pop(@dirparts);
@extparts = split(/\./, $fname);
$seqlab = $extparts[0];
$wigFile = "$seqlab.wig"; # output wig file

# process bed file
%seqhash = ();
open(IN, $locsFile) || die "Can't open $locsFile";
while (<IN>) {
    $line = $_;
    chomp($line);
    
    @arr = split(/\t/, $line);

    $id = $arr[0];
    $chr = $arr[1];
    $start = $arr[2];
    $end = $arr[3];
    $strand = $arr[4];

    $seqhash{$id}{'chr'} = $chr;
    $seqhash{$id}{'strand'} = $strand;
    $seqhash{$id}{'start'} = $start;
    $seqhash{$id}{'end'} = $end;
}
close(IN);

# process results file
open(IN, "$inFile") || die "Can't open $inFile";
    
# read through header
while (<IN> =~ /^\%/) {
}

# read value vector
@arr = ();
$cnt = 0;
while (<IN>) {
    $line = $_;
    chomp($line);
    $line =~ s/^\s+//; # remove leading whitespace
    $arr[$cnt] = $line;
    $cnt++;
}

close(IN);

$length = $#arr;


# print wig file

$header="track type=wiggle_0 name=\"S-Peaker\" description=\"Single-Peak TSS Probability\" visibility=full viewLimits=0.0:1.0 autoScale=off maxHeightPixels=50:40:30 color=255,0,0 yLineMark=0.5 yLineOnOff=off";

open(OUT, ">$outdir/$wigFile");
if (exists($seqhash{$seqlab})) {
    $chr = $seqhash{$seqlab}{'chr'};
    $strand = $seqhash{$seqlab}{'strand'};
    $start = $seqhash{$seqlab}{'start'} + $TRIM;
    $end = $seqhash{$seqlab}{'end'} - $TRIM;
    $browserpos = "browser position $chr:$start-$end";

    print OUT "$browserpos\n";
    print OUT "$header\n";
    print OUT "fixedStep chrom=$chr start=$start step=$step\n";

    if ($strand eq "+") {
	for ($i=0+$TRIM; $i<=$#arr-$TRIM; $i++) {
	    print OUT "$arr[$i]\n";
	}
    }
    else {
	for ($i=$#arr-$TRIM; $i>=0+$TRIM; $i--) {
	    print OUT "$arr[$i]\n";
	}
    }
}
close(OUT);
