#!/bin/bash

seqsFile=$1
locsFile=$2

matrixMarketOnly=T
# To generate an additional standard-format feature file, uncomment the line below
# matrixMarketOnly=F

increment=1
winDefFwd=Annotation-Supported.fwd.table
winDefRev=Annotation-Supported.rev.table
pwmFile=Annotation-Supported.mat
modelFile=Annotation-Supported.model

featuresDir=$1.features
resultsDir=$1.classification
wigDir=$1.customtracks


echo "Generating features..."

if [ ! -d $featuresDir ]
then
    mkdir $featuresDir
fi

thisDir=`pwd`
cd ../LogLikScanner/classes
java loglikscan.SPeaker $thisDir/$winDefFwd $thisDir/$winDefRev $thisDir/$pwmFile $thisDir/$seqsFile $increment $matrixMarketOnly $thisDir/$featuresDir

echo "Performing classification..."

cd $thisDir
if [ ! -d $resultsDir ]
then
    mkdir $resultsDir
fi

if [ ! -d $wigDir ]
then
    mkdir $wigDir
fi

cd $thisDir/$featuresDir
files=`ls *.vals`
for fname in $files
do
    # Construct MatrixMarket file for input to l1_logreg
    hdrFile=${fname%.vals}.hdr
    valsFile=$fname
    mmFile=${fname%.vals}
    cat $hdrFile $valsFile > $mmFile
    rm $hdrFile $valsFile
    
    # Classification
    resultFile=$thisDir/$resultsDir/${fname%.mm.vals}.result
    classOutputFile=$thisDir/$resultsDir/${fname%.mm.vals}.l1_logreg.output
    l1_logreg_classify -p $thisDir/$modelFile $mmFile $resultFile > $classOutputFile 2>&1 
    if [ ! -e $resultFile ]
    then
	echo "Classification failed."
	echo "Is l1_logreg_classify installed, and can it be called from the current directory?"
	echo "For detailed error messages see the file $classOutputFile"
	exit
    else
	echo "Performing postprocessing..."
    fi

    # Smoothing with median filter
    smoothHalfWin=2
    smoothedResultFile=$resultFile.smoothed
    $thisDir/postprocessing/results_to_smoothed_results.pl $smoothHalfWin $resultFile $smoothedResultFile
 
    # Generate wig file for viewing probability output as a UCSC custom track
    if [ -e $thisDir/$locsFile ]
    then
	$thisDir/postprocessing/results_to_wig.pl $increment $smoothedResultFile $thisDir/$locsFile $thisDir/$wigDir
    fi

done
